"""Factories for randomised AFL data sets for testing purposes."""

from .data_factory import CandyStore
